# Comparison with AmpForm

The following notebooks investigate the difference between the amplitude models formulated by {mod}`ampform` and {mod}`ampform_dpd`.

```{toctree}
---
maxdepth: 1
---
comparison/d2kkk
comparison/jpsi2pipipi
comparison/jpsi2phipipi
```
